@@ -4,6 +4,7 @@
 package org.gcube.portlets.user.td.openwidget.client;
 
 import java.util.ArrayList;
+import java.util.Date;
 import java.util.List;
 
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
@@ -11,6 +12,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedExcep
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.TabResource;
 import org.gcube.portlets.user.td.openwidget.client.resources.ResourceBundleTDOpen;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.RibbonEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.RibbonType;
@@ -20,6 +22,7 @@ import org.gcube.portlets.user.td.wizardwidget.client.util.UtilsGXT3;
 
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.cell.client.AbstractCell;
+import com.google.gwt.cell.client.DateCell;
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.core.client.Scheduler.ScheduledCommand;
@@ -29,6 +32,7 @@ import com.google.gwt.event.logical.shared.HasSelectionHandlers;
 import com.google.gwt.event.logical.shared.SelectionEvent;
 import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.gwt.event.shared.HandlerRegistration;
+import com.google.gwt.i18n.client.DateTimeFormat;
 import com.google.gwt.safehtml.shared.SafeHtml;
 import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -76,12 +80,18 @@ import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
 public class TabResourcesSelectionPanel extends ContentPanel implements
 		HasSelectionHandlers<TabResource> {
 
+	private static final DateTimeFormat sdf = DateTimeFormat
+			.getFormat("yyyy-MM-dd HH:mm");
+
 	interface NameTooltipTemplates extends XTemplates {
 		@XTemplate("<span qtip=\"{desc}\" qtitle=\"{value}\">{value}</span>")
 		SafeHtml format(String value, String desc);
 
 	}
-
+	
+	private CommonMessages msgsCommon;
+	private TDOpenMessages msgs;
+	
 	private Grid<TabResource> grid;
 	private ResourceBundle res;
 	private Menu contextMenu;
@@ -89,13 +99,18 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 	private TabResource removableTR;
 
 	private TabResourcesSelectionCard parent;
+	
+	
 
 	public TabResourcesSelectionPanel(TabResourcesSelectionCard parent,
 			ResourceBundle res) {
 		this.res = res;
 		this.parent = parent;
 		Log.debug("TabResourcesSelectionPanel");
-		init();
+		
+		initMessages();
+		initWindow();
+		
 		try {
 			createContextMenu();
 		} catch (Throwable e) {
@@ -110,30 +125,35 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 			e.printStackTrace();
 		}
 	}
+	
+	protected void initMessages(){
+		msgs = GWT.create(TDOpenMessages.class);
+		msgsCommon = GWT.create(CommonMessages.class);
+	}
 
-	protected void init() {
+	protected void initWindow() {
 		setHeaderVisible(false);
 	}
 
 	protected void buildPanel() {
 
 		ToolBar toolBar = new ToolBar();
-		toolBar.add(new LabelToolItem("Search: "));
+		toolBar.add(new LabelToolItem(msgsCommon.toolItemSearchLabel()));
 		final TextField searchField = new TextField();
 		toolBar.add(searchField);
 
 		TextButton btnReload = new TextButton();
 		// btnReload.setText("Reload");
 		btnReload.setIcon(res.refresh16());
-		btnReload.setToolTip("Reload");
+		btnReload.setToolTip(msgsCommon.toolItemReloadLabel());
 		toolBar.add(btnReload);
 
 		IdentityValueProvider<TabResource> identity = new IdentityValueProvider<TabResource>();
 		final CheckBoxSelectionModel<TabResource> sm = new CheckBoxSelectionModel<TabResource>(
 				identity);
 
-		TabResourcesProperties properties = GWT
-				.create(TabResourcesProperties.class);
+		TabResourceProperties properties = GWT
+				.create(TabResourceProperties.class);
 
 		final ExtendedListStore<TabResource> store = new ExtendedListStore<TabResource>(
 				properties.id());
@@ -160,39 +180,21 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		store.setEnableFilters(true);
 
 		ColumnConfig<TabResource, String> nameColumn = new ColumnConfig<TabResource, String>(
-				properties.name(), 90, "Name");
-
-		/*
-		 * nameColumn.setCell( new AbstractCell<String>() {
-		 * 
-		 * @Override public void render(Context context, String value,
-		 * SafeHtmlBuilder sb) { TabResource
-		 * tabResource=store.get(context.getIndex());
-		 * 
-		 * final NameTooltipTemplates nameToolTipTemplates = GWT
-		 * .create(NameTooltipTemplates.class); String valueSafe=""; String
-		 * descriptionSafe="";
-		 * 
-		 * if(value!=null){ valueSafe=SafeHtmlUtils.htmlEscape(value); }
-		 * if(tabResource!=null && tabResource.getAgency()!=null){
-		 * descriptionSafe=SafeHtmlUtils.htmlEscape(tabResource.getAgency()); }
-		 * sb.append(nameToolTipTemplates.format(valueSafe, descriptionSafe));
-		 * 
-		 * } });
-		 */
-
+				properties.name(), 90, msgs.tabResourcesSelectionPanelColumnNameLabel());
 		ColumnConfig<TabResource, String> typeColumn = new ColumnConfig<TabResource, String>(
-				properties.tabResourceType(), 30, "Type");
+				properties.tabResourceType(), 30, msgs.tabResourcesSelectionPanelColumnTypeLabel());
 		ColumnConfig<TabResource, String> tableTypeNameColumn = new ColumnConfig<TabResource, String>(
-				properties.tableTypeName(), 30, "Table Type");
+				properties.tableTypeName(), 30, msgs.tabResourcesSelectionPanelColumnTableTypeLabel());
 		ColumnConfig<TabResource, Boolean> lockedColumn = new ColumnConfig<TabResource, Boolean>(
-				properties.locked(), 20, "Lock");
+				properties.locked(), 20, msgs.tabResourcesSelectionPanelColumnLockLabel());
 		ColumnConfig<TabResource, String> agencyColumn = new ColumnConfig<TabResource, String>(
-				properties.agency(), 60, "Agency");
+				properties.agency(), 60, msgs.tabResourcesSelectionPanelColumnAgencyLabel());
 		ColumnConfig<TabResource, String> ownerColumn = new ColumnConfig<TabResource, String>(
-				properties.ownerLogin(), 70, "Owner");
-		ColumnConfig<TabResource, String> dateColumn = new ColumnConfig<TabResource, String>(
-				properties.date(), 50, "Creation Date");
+				properties.ownerLogin(), 70, msgs.tabResourcesSelectionPanelColumnOwnerLabel());
+		ColumnConfig<TabResource, Date> dateColumn = new ColumnConfig<TabResource, Date>(
+				properties.date(), 50, msgs.tabResourcesSelectionPanelColumnCreationDateLabel());
+
+		dateColumn.setCell(new DateCell(sdf));
 
 		lockedColumn.setCell(new AbstractCell<Boolean>() {
 
@@ -306,7 +308,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	protected void createContextMenu() {
 		contextMenu = new Menu();
-		MenuItem deleteTRItem = new MenuItem("Delete");
+		MenuItem deleteTRItem = new MenuItem(msgs.tabResourcesSelectionPanelContextMenuDelete());
 		deleteTRItem.setId("DeleteTR");
 		deleteTRItem.setIcon(ResourceBundleTDOpen.INSTANCE.delete());
 		deleteTRItem.addSelectionHandler(new SelectionHandler<Item>() {
@@ -323,7 +325,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		contextMenu.add(deleteTRItem);
 
 		MenuItem infoItem = new MenuItem();
-		infoItem.setText("Info");
+		infoItem.setText(msgs.tabResourcesSelectionPanelContextMenuInfo());
 		infoItem.setIcon(ResourceBundleTDOpen.INSTANCE.information());
 		infoItem.addSelectionHandler(new SelectionHandler<Item>() {
 
@@ -343,16 +345,17 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	protected void openInfoDialog(TabResource tabResource) {
 		final TabResourceInfoDialog tabResourceInfoDialog = new TabResourceInfoDialog(
-				tabResource);
+				tabResource, parent.getEventBus());
 		tabResourceInfoDialog.show();
 	}
 
 	protected void requestInfo(TabResource tabResource) {
-		if(tabResource.isLocked()){
-			UtilsGXT3.alert("Attention", "Tabular Resource is locked no info available!");
+		if (tabResource.isLocked()) {
+			UtilsGXT3.alert(msgsCommon.attention(),
+					msgs.attentionTabularResourceIsLockedNoInfoAvailable());
 			return;
 		}
-	
+
 		TDGWTServiceAsync.INSTANCE.getTabResourceInformation(
 				tabResource.getTrId(), new AsyncCallback<TabResource>() {
 
@@ -371,16 +374,17 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error("Tabular Resource is Locked: "
 										+ caught.getLocalizedMessage());
-								parent.showErrorAndHide("Error",
-										caught.getLocalizedMessage(), "", caught);
-								
-								
+								parent.showErrorAndHide(msgsCommon.errorLocked(),
+										caught.getLocalizedMessage(), "",
+										caught);
+
 							} else {
 								Log.error("Error: "
 										+ caught.getLocalizedMessage());
-								parent.showErrorAndHide("Error",
-										caught.getLocalizedMessage(), "", caught);
-								
+								parent.showErrorAndHide(msgsCommon.error(),
+										caught.getLocalizedMessage(), "",
+										caught);
+
 							}
 
 						}
@@ -402,10 +406,6 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 				&& item.getAgency().toLowerCase()
 						.contains(searchTerm.toLowerCase()))
 			return true;
-		if (item.getDate() != null
-				&& item.getDate().toLowerCase()
-						.contains(searchTerm.toLowerCase()))
-			return true;
 		if (item.getOwnerLogin() != null
 				&& item.getOwnerLogin().toLowerCase()
 						.contains(searchTerm.toLowerCase()))
@@ -427,7 +427,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 						} else {
 							Log.error("Error retrieving tabular resource: "
 									+ caught.getLocalizedMessage());
-							parent.showErrorAndHide("Error",
+							parent.showErrorAndHide(msgsCommon.error(),
 									caught.getLocalizedMessage(), "", caught);
 						}
 						callback.onFailure(caught);
@@ -480,8 +480,8 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 
 	protected void deleteTR(TabResource tabResource) {
 		removableTR = tabResource;
-		final ConfirmMessageBox mb = new ConfirmMessageBox("Delete",
-				"Would you like to delete this tabular resource?");
+		final ConfirmMessageBox mb = new ConfirmMessageBox(msgs.deleteHead(),
+				msgs.questionWouldYouLikeToDeleteThisTabularResource());
 		// Next in GXT 3.1.1
 		mb.addDialogHideHandler(new DialogHideHandler() {
 
@@ -528,13 +528,13 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 
 							} else {
 								Log.error("Error on delete TabResource: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
+								UtilsGXT3.alert(msgsCommon.error(),
 										caught.getLocalizedMessage());
 							}
 						}
